Overview
-chrcvt is a vector font converter. It is able to convert a "BGI Stroked
+chrcvt65 is a vector font converter. It is able to convert a "BGI Stroked
Font" to a compact TGI native vector font. See the function for usage.
@@ -26,7 +26,7 @@ url="funcref.html#tgi_load_vectorfont" name="tgi_load_vectorfont"> for usage.
Usage
-The chrcvt utility converts the font of one Borland file to its cc65 equivalent.
+The chrcvt65 utility converts the font of one Borland file to its cc65 equivalent.
Command line option overview
@@ -35,7 +35,7 @@ The program may be called as follows:
---------------------------------------------------------------------------
-Usage: chrcvt [options] file [options] [file]
+Usage: chrcvt65 [options] file [options] [file]
Short options:
-h Help (this text)
-v Be more verbose
@@ -80,7 +80,7 @@ in TCH format to a new file.
Example output for the command
-chrcvt --verbose LITT.CHR
+chrcvt65 --verbose LITT.CHR
BGI Stroked Font V1.1 - Aug 12, 1991
@@ -91,7 +91,7 @@ Copyright (c) 1987,1988 Borland International
Copyright
-chrcvt is (C) Copyright 2009, Ullrich von Bassewitz. For usage of the
+chrcvt65 is (C) Copyright 2009, Ullrich von Bassewitz. For usage of the
binaries and/or sources the following conditions apply:
This software is provided 'as-is', without any expressed or implied
diff --git a/doc/index.sgml b/doc/index.sgml
index 68f755a29..44b58ef5e 100644
--- a/doc/index.sgml
+++ b/doc/index.sgml
@@ -18,7 +18,7 @@
Describes the cc65 C compiler.
-
+
Describes the vector font converter.
@@ -31,7 +31,7 @@
Describes the da65 6502/65C02 disassembler.
- Describes the GEOS resource compiler (grc65).
+ Describes the GEOS resource compiler.
Describes the ld65 linker.
diff --git a/src/Makefile b/src/Makefile
index 5aafc4bb8..f10c189b3 100644
--- a/src/Makefile
+++ b/src/Makefile
@@ -2,16 +2,17 @@ ifneq ($(shell echo),)
CMD_EXE = 1
endif
-PROGS = ar65 \
- ca65 \
- cc65 \
- cl65 \
- co65 \
- da65 \
- grc65 \
- ld65 \
- od65 \
- sim65 \
+PROGS = ar65 \
+ ca65 \
+ cc65 \
+ chrcvt65 \
+ cl65 \
+ co65 \
+ da65 \
+ grc65 \
+ ld65 \
+ od65 \
+ sim65 \
sp65
.PHONY: all mostlyclean clean install zip avail unavail bin $(PROGS)
diff --git a/src/chrcvt/error.c b/src/chrcvt65/error.c
similarity index 97%
rename from src/chrcvt/error.c
rename to src/chrcvt65/error.c
index 424080d83..d6bc57fdf 100644
--- a/src/chrcvt/error.c
+++ b/src/chrcvt65/error.c
@@ -2,7 +2,7 @@
/* */
/* error.c */
/* */
-/* Error handling for the chrcvt vector font converter */
+/* Error handling for the chrcvt65 vector font converter */
/* */
/* */
/* */
diff --git a/src/chrcvt/error.h b/src/chrcvt65/error.h
similarity index 97%
rename from src/chrcvt/error.h
rename to src/chrcvt65/error.h
index 93f59ccfd..c5d1474e9 100644
--- a/src/chrcvt/error.h
+++ b/src/chrcvt65/error.h
@@ -2,7 +2,7 @@
/* */
/* error.h */
/* */
-/* Error handling for the chrcvt vector font converter */
+/* Error handling for the chrcvt65 vector font converter */
/* */
/* */
/* */
diff --git a/src/chrcvt/main.c b/src/chrcvt65/main.c
similarity index 98%
rename from src/chrcvt/main.c
rename to src/chrcvt65/main.c
index 7b1c3219e..8685e06b9 100644
--- a/src/chrcvt/main.c
+++ b/src/chrcvt65/main.c
@@ -2,7 +2,7 @@
/* */
/* main.c */
/* */
/* Main program of the chrcvt vector font converter */
/* */
/* */
/* */
@@ -46,7 +46,7 @@
#include "xmalloc.h"
#include "version.h"
-/* chrcvt */
+/* chrcvt65 */
#include "error.h"
@@ -219,8 +219,7 @@ static void OptVersion (const char* Opt attribute ((unused)),
/* Print the assembler version */
{
fprintf (stderr,
- "%s V%s - (C) Copyright 2009, Ullrich von Bassewitz\n",
- ProgName, GetVersionAsString ());
+ "%s V%s\n", ProgName, GetVersionAsString ());
}
@@ -482,7 +481,7 @@ int main (int argc, char* argv [])
unsigned I;
/* Initialize the cmdline module */
- InitCmdLine (&argc, &argv, "chrcvt");
+ InitCmdLine (&argc, &argv, "chrcvt65");
/* Check the parameters */
I = 1;
@@ -2,7 +2,7 @@
/* main.c */
/* */
-/* Main program of the chrcvt vector font converter */
+/* Main program of the chrcvt65 vector font converter */
/* */
/* */
--
2.39.5